| Title: | Graphic Visualization of the Birds' Molt |
|---|---|
| Description: | Graphical visualization of the birds' molt to facilitate the creation of molting graph for passerines having 9 (Rmolt(data,9)) or 10 primaries (Rmolt(data,10)), and also only for the 10 first primaries (Rmolt(data,"10_0")). |
| Authors: | Martin Bozon [cre, aut] |
| Maintainer: | Martin Bozon <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0.0 |
| Built: | 2026-05-10 07:12:21 UTC |
| Source: | https://github.com/martinbozon/rmolt |
A dataset containing the percentage of molting feathers in a 9 primarie bird
dcbdcb
A data frame with 47 rows and 2 variables:
name of the feather
percentage of molting (between 0 and 1)
...
A dataset containing the percentage of molting feathers in an only 10 primaries bird
dfdf
A data frame with 10 rows and 2 variables:
name of the feather
percentage of molting (between 0 and 1)
...
A dataset containing the percentage of molting feathers in a 10 primarie bird
fcffcf
A data frame with 48 rows and 2 variables:
name of the feather
percentage of molting (between 0 and 1)
...
moult_color
i |
a value to run the loop |
data |
a data table to choose the color |
color of the feather depending of the percentage, called for side effect
percentage
percentage()percentage()
Don't return value, just display percentage box and color on graphs
primarie_10
primarie_10(i, data)primarie_10(i, data)
i |
a value to run the loop |
data |
a data table to choose the color |
No return value but etablish a molt graph for a 9 primaries' bird @examples primarie_10(2,fcf)
primarie_9
i |
a value to run the loop |
data |
a data table to choose the color |
No return value but etablish a molt graph for a 9 primaries' bird
primarie_9(2,dcb)primarie_9(2,dcb)
An easy way to create molt graph of passerines wings. 3 different graph available: a full passerine wing with 9 primaries; argument : primarie=9 a full passerine wing with 10 primaries; argument: primarie=10 only the 10 primaries; argument: primarie="10_0"
The data table must have 2 rows and the order of the feathers must be like this:
for 9 primaries: c("CM10","CM9","CM8","CM7","CM6","CM5","CM4","CM3","CM2","CM1", "CP1", "CP2", "CP3","CP4","CP5","CP6","CP7","CP8", "CP9", "CC", "A1", "A2", "A3", "T3","T2","T1", "S6", "S5","S4","S3","S2","S1" ,"P1", "P2","P3","P4","P5","P6","P7","P8","P9", "R1","R2","R3","R4","R5","R6")
for 10 primaries: c("CM10","CM9","CM8","CM7","CM6","CM5","CM4","CM3","CM2","CM1", "CP1", "CP2", "CP3","CP4","CP5","CP6","CP7","CP8", "CP9", "CC", "A1", "A2", "A3", "T3","T2","T1", "S6", "S5","S4","S3","S2","S1" ,"P1", "P2","P3","P4","P5","P6","P7","P8","P9","P10" "R1","R2","R3","R4","R5","R6")
for only 10 primaries: c("P1", "P2","P3","P4","P5","P6","P7","P8","P9","P10")
dcb, fcf and df are examples data table include in this package
data |
a data table to create the graph |
primaries |
an argument to choose the graph |
Rmolt
Don't return value, print molt graph.
c(person("Martin","Bozon",email = "[email protected]", role = c("cre","aut")))
data(df) Rmolt(df,"10_0") data(fcf) Rmolt(fcf,10) data(dcb) Rmolt(dcb,9)data(df) Rmolt(df,"10_0") data(fcf) Rmolt(fcf,10) data(dcb) Rmolt(dcb,9)